@@ -3,10 +3,11 @@ Accounts Connection
 ===================
 """
 
-from typing import Union, Optional, List
+from typing import List, Optional, Union
 
 from deepcrawl.api import ApiConnection
 from deepcrawl.api.api_endpoints import get_api_endpoint
+
 from .account import DeepCrawlAccount
 
 
@@ -24,7 +25,8 @@ class AccountConnection(ApiConnection):
     """
 
     def create_account(self, account_data: dict) -> DeepCrawlAccount:
-        """Create account
+        """
+        Create account
 
         .. code-block::
 
@@ -63,7 +65,8 @@ class AccountConnection(ApiConnection):
         return DeepCrawlAccount(account_data=response.json())
 
     def get_account(self, account_id: Union[int, str]) -> DeepCrawlAccount:
-        """Get account
+        """
+        Get account
 
         >>> connection.get_account(0)
         [0] DeepCrawlAccount
@@ -78,7 +81,8 @@ class AccountConnection(ApiConnection):
         return DeepCrawlAccount(account_data=response.json())
 
     def update_account(self, account_id: Union[int, str], account_data: dict) -> DeepCrawlAccount:
-        """Update account
+        """
+        Update account
 
         >>> connection.update_account("0", account_data)
         [0] DeepCrawlAccount
@@ -95,7 +99,8 @@ class AccountConnection(ApiConnection):
         return DeepCrawlAccount(account_data=response.json())
 
     def get_accounts(self, filters: Optional[dict] = None, **kwargs) -> List[DeepCrawlAccount]:
-        """Get all accounts associated with the credentials used to generate the connection
+        """
+        Get all accounts associated with the credentials used to generate the connection
 
         >>> connection.get_accounts()
         [[0] DeepCrawlAccount,
