@@ -2,12 +2,13 @@
 Crawls Connection
 =================
 """
-from typing import Union, Optional, List
+from typing import List, Optional, Union
 
 from requests import Response
 
 from deepcrawl.api import ApiConnection
 from deepcrawl.api.api_endpoints import get_api_endpoint
+
 from .crawl import DeepCrawlCrawl
 
 
@@ -38,7 +39,8 @@ class CrawlConnection(ApiConnection):
     """
 
     def start_crawl(self, account_id: Union[int, str], project_id: Union[int, str]) -> Response:
-        """Start Crawl
+        """
+        Start Crawl
 
         >>> response = connection.start_crawl(0, 1)
         >>> response.status_code
@@ -57,7 +59,8 @@ class CrawlConnection(ApiConnection):
     def create_crawl(
             self, account_id: Union[int, str], project_id: Union[int, str], crawl_data: dict
     ) -> DeepCrawlCrawl:
-        """Create crawl
+        """
+        Create crawl
 
         .. code-block::
 
@@ -87,7 +90,8 @@ class CrawlConnection(ApiConnection):
     def get_crawl(
             self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str]
     ) -> DeepCrawlCrawl:
-        """Get crawl
+        """
+        Get crawl
 
         >>> connection.get_crawl(0, 1, 3)
         [0 1 3] 2020-04-23 11:10:11+00:00
@@ -112,7 +116,8 @@ class CrawlConnection(ApiConnection):
             self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str],
             crawl_data: dict
     ) -> DeepCrawlCrawl:
-        """Update crawl
+        """
+        Update crawl
 
         >>> connection.update_crawl(0, 1, 3, crawl_data)
         [0 1 3] 2020-04-23 11:10:11+00:00
@@ -138,7 +143,8 @@ class CrawlConnection(ApiConnection):
     def delete_crawl(
             self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str]
     ) -> Response:
-        """Delete crawl
+        """
+        Delete crawl
 
         >>> response = connection.delete_crawl(0, 1, 3)
         >>> response.status_code
@@ -161,7 +167,8 @@ class CrawlConnection(ApiConnection):
     def get_crawls(
             self, account_id: Union[int, str], project_id: Union[int, str], filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlCrawl]:
-        """Get crawls
+        """
+        Get crawls
 
         >>> connection.get_crawls(0, 1)
         [[0 1 3] 2020-04-23 11:10:11+00:00, [0 1 4] 2020-04-23 11:10:11+00:00]
