@@ -3,13 +3,14 @@ Downloads Connection
 ====================
 """
 
-from typing import List, Union, Optional
+from typing import List, Optional, Union
 
 from requests import Response
 
 from deepcrawl.api import ApiConnection
 from deepcrawl.api.api_endpoints import get_api_endpoint
 from deepcrawl.downloads.download import DeepCrawlReportDownload
+
 from .download import DeepCrawlCrawlDownloads
 
 
@@ -38,7 +39,8 @@ class DownloadConnection(ApiConnection):
             self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str],
             filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlCrawlDownloads]:
-        """Get crawl downloads
+        """
+        Get crawl downloads
 
         >>> connection.get_crawl_downloads(0, 1, 2)
         [[6] Report Template_11_basic - csv_zip (draft),
@@ -79,7 +81,8 @@ class DownloadConnection(ApiConnection):
             self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str],
             report_id: str, download_data: dict
     ) -> DeepCrawlReportDownload:
-        """Create report download
+        """
+        Create report download
 
         .. code-block::
 
@@ -118,7 +121,8 @@ class DownloadConnection(ApiConnection):
             self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str],
             report_id: str, report_download_id: Union[int, str]
     ) -> DeepCrawlReportDownload:
-        """Get report download
+        """
+        Get report download
 
         >>> connection.get_report_download(0, 1, 2, "duplicate_body_content:basic", 6)
         <deepcrawl.downloads.download.DeepCrawlReportDownload at 0x108a20600>
@@ -151,7 +155,8 @@ class DownloadConnection(ApiConnection):
             self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str],
             report_id: str, report_download_id: Union[int, str]
     ) -> Response:
-        """Delete report download
+        """
+        Delete report download
 
         >>> response = connection.delete_report_download(0, 1, 2, "duplicate_body_content:basic", 6)
         >>> response.status_code
@@ -180,7 +185,8 @@ class DownloadConnection(ApiConnection):
             self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str],
             report_id: str, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlReportDownload]:
-        """Get report downloads
+        """
+        Get report downloads
 
         >>> connection.get_report_downloads(0, 1, 2)
         [<deepcrawl.downloads.download.DeepCrawlReportDownload at 0x108a20600>,
