@@ -3,12 +3,13 @@ Projects Connection
 ===================
 """
 
-from typing import Union, Optional, List
+from typing import List, Optional, Union
 
 from requests import Response
 
 from deepcrawl.api import ApiConnection
 from deepcrawl.api.api_endpoints import get_api_endpoint
+
 from .issues import DeepCrawlIssue
 from .majestic_settings import MajesticSettings
 from .project_settings import ProjectSettings
@@ -61,7 +62,8 @@ class ProjectConnection(ApiConnection):
     """
 
     def create_project(self, account_id: Union[int, str], project_settings: dict) -> DeepCrawlProject:
-        """Create a project.
+        """
+        Create a project.
         Project settings argument can be dict or a ProjectSettings instance.
 
         .. code-block::
@@ -81,9 +83,9 @@ class ProjectConnection(ApiConnection):
                 "urls_excluded": ["url|regex"],
                 "page_groupings": [
                     {
-                      "name": str,
-                      "url_match": "url|regex",
-                      "crawl_sample": float
+                        "name": str,
+                        "url_match": "url|regex",
+                        "crawl_sample": float
                     }
                 ],
                 "crawl_css_js": bool,
@@ -103,19 +105,19 @@ class ProjectConnection(ApiConnection):
                 "mobile_custom_header_user_agent_short": str,
                 "custom_extractions": [
                     {
-                      "label": str,
-                      "regex": "regec",
-                      "clean_html_tags": bool,
-                      "match_number_from": int,
-                      "match_number_to": int,
-                      "filter": "regex"
+                        "label": str,
+                        "regex": "regec",
+                        "clean_html_tags": bool,
+                        "match_number_from": int,
+                        "match_number_to": int,
+                        "filter": "regex"
                     }
                 ],
                 "robots_overwrite": str,
                 "custom_dns": [
                     {
-                      "hostname": str,
-                      "ip_address": str
+                        "hostname": str,
+                        "ip_address": str
                     }
                 ],
                 "site_test": "url",
@@ -125,8 +127,8 @@ class ProjectConnection(ApiConnection):
                 "url_rewrite_query_parameters": [str],
                 "url_rewrite_regex_parameters": [
                     {
-                      "match_from": "regex",
-                      "match_to": "regex"
+                        "match_from": "regex",
+                        "match_to": "regex"
                     }
                 ],
                 "use_rewrite_rules": bool,
@@ -158,7 +160,8 @@ class ProjectConnection(ApiConnection):
         return DeepCrawlProject(project_data=response.json(), account_id=account_id)
 
     def get_project(self, account_id: Union[int, str], project_id: Union[int, str]) -> DeepCrawlProject:
-        """Get project
+        """
+        Get project
 
         >>> connection.get_project(0, 1)
         [0 1] www.test.com Project
@@ -177,7 +180,8 @@ class ProjectConnection(ApiConnection):
     def update_project_settings(
             self, account_id: Union[int, str], project_id: Union[int, str], settings: dict
     ) -> DeepCrawlProject:
-        """Update the project settings.
+        """
+        Update the project settings.
         Settings argument can be dict or a ProjectSettings instance.
 
         >>> connection.update_project_settings(0, 1, settings)
@@ -200,7 +204,8 @@ class ProjectConnection(ApiConnection):
         return DeepCrawlProject(project_data=response.json(), account_id=account_id)
 
     def delete_project(self, account_id: Union[int, str], project_id: Union[int, str]) -> Response:
-        """Delete project
+        """
+        Delete project
 
         >>> response = connection.delete_project(0, 1)
         >>> response.status_code
@@ -218,7 +223,8 @@ class ProjectConnection(ApiConnection):
     def get_projects(
             self, account_id: Union[int, str], filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlProject]:
-        """Get projects
+        """
+        Get projects
 
         >>> connection.get_projects(0)
         [[0 1] www.test.com Project, [0 2] www.test2.com Project]
@@ -249,7 +255,8 @@ class ProjectConnection(ApiConnection):
     def create_project_upload(
             self, account_id: Union[int, str], project_id: Union[int, str], upload_data: dict, files: list
     ) -> DeepCrawlProjectUpload:
-        """Create a project upload
+        """
+        Create a project upload
         Project uploads allow you upload files to be used within a crawl such as log files and backlinks,
         this allows you to utilise outputs from other systems with DeepCrawl.
 
@@ -283,7 +290,8 @@ class ProjectConnection(ApiConnection):
     def get_project_upload(
             self, account_id: Union[int, str], project_id: Union[int, str], project_upload_id: Union[int, str]
     ) -> DeepCrawlProjectUpload:
-        """Get project upload
+        """
+        Get project upload
 
         >>> connection.get_project_upload(0, 1, 5)
         [0 1] filename.csv
@@ -307,7 +315,8 @@ class ProjectConnection(ApiConnection):
     def enable_project_upload(
             self, account_id: Union[int, str], project_id: Union[int, str], project_upload_id: Union[int, str]
     ) -> DeepCrawlProjectUpload:
-        """Enable project upload
+        """
+        Enable project upload
 
         :param account_id: account id
         :type account_id: int or str
@@ -328,7 +337,8 @@ class ProjectConnection(ApiConnection):
     def disable_project_upload(
             self, account_id: Union[int, str], project_id: Union[int, str], project_upload_id: Union[int, str]
     ) -> DeepCrawlProjectUpload:
-        """Disable project upload
+        """
+        Disable project upload
 
         :param account_id: account id
         :type account_id: int or str
@@ -349,7 +359,8 @@ class ProjectConnection(ApiConnection):
     def delete_project_upload(
             self, account_id: Union[int, str], project_id: Union[int, str], project_upload_id: Union[int, str]
     ) -> Response:
-        """Delete project upload
+        """
+        Delete project upload
 
         >>> response = connection.delete_project_upload(0, 1, 5)
         >>> response.status_code
@@ -371,7 +382,8 @@ class ProjectConnection(ApiConnection):
     def get_project_uploads(
             self, account_id: Union[int, str], project_id: Union[int, str], filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlProjectUpload]:
-        """Get project uploads
+        """
+        Get project uploads
 
         >>> connection.get_project_uploads(0, 1)
         [[0 1] filename.csv, [0 1] filename2.csv]
@@ -412,7 +424,8 @@ class ProjectConnection(ApiConnection):
     """
 
     def get_majestic_settings(self, account_id: Union[int, str], project_id: Union[int, str]) -> MajesticSettings:
-        """Get projects majestic settings
+        """
+        Get projects majestic settings
 
         >>> connection.get_majestic_settings(0, 1)
         <deepcrawl.projects.majestic_settings.MajesticSettings at 0x108b29600>
@@ -431,7 +444,8 @@ class ProjectConnection(ApiConnection):
     def update_majestic_settings(
             self, account_id: Union[int, str], project_id: Union[int, str], majestic_settings: dict
     ) -> MajesticSettings:
-        """Update majestic settings
+        """
+        Update majestic settings
         Majestic settings argument can be dict or a MajesticSettings instance.
 
         .. code-block::
@@ -468,7 +482,8 @@ class ProjectConnection(ApiConnection):
     def create_issue(
             self, account_id: Union[int, str], project_id: Union[int, str], issue_data: dict
     ) -> DeepCrawlIssue:
-        """Create issue
+        """
+        Create issue
 
         .. code-block::
 
@@ -510,7 +525,8 @@ class ProjectConnection(ApiConnection):
     def get_issue(
             self, account_id: Union[int, str], project_id: Union[int, str], issue_id: Union[int, str]
     ) -> DeepCrawlIssue:
-        """Get issue
+        """
+        Get issue
 
         >>> connection.get_issue(0, 1, 2)
         [0 1 3] Issue Title
@@ -534,7 +550,8 @@ class ProjectConnection(ApiConnection):
     def update_issue(
             self, account_id: Union[int, str], project_id: Union[int, str], issue_id: Union[int, str], issue_data: dict
     ) -> DeepCrawlIssue:
-        """Update issue
+        """
+        Update issue
 
         >>> connection.update_issue(0, 1, 2, issue_data)
         [0 1 3] Issue Title
@@ -560,7 +577,8 @@ class ProjectConnection(ApiConnection):
     def delete_issue(
             self, account_id: Union[int, str], project_id: Union[int, str], issue_id: Union[int, str]
     ) -> Response:
-        """Delete issue
+        """
+        Delete issue
 
         >>> response = connection.delete_issue(0, 1, 2)
         >>> response.status_code
@@ -580,7 +598,8 @@ class ProjectConnection(ApiConnection):
     def get_issues(
             self, account_id: Union[int, str], project_id: Union[int, str], filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlIssue]:
-        """Get issues
+        """
+        Get issues
 
         >>> connection.get_issues(0, 1)
         [[0 1 3] Issue Title, [0 1 3] Issue Title2]
@@ -611,7 +630,8 @@ class ProjectConnection(ApiConnection):
     def create_schedule(
             self, account_id: Union[int, str], project_id: Union[int, str], schedule_data: dict
     ) -> DeepCrawlSchedule:
-        """Create schedule
+        """
+        Create schedule
 
         >>> connection.create_schedule(0, 1, schedule_data)
         [0 1 4] 2021-03-22 12:09:11+00:00
@@ -632,7 +652,8 @@ class ProjectConnection(ApiConnection):
     def get_schedule(
             self, account_id: Union[int, str], project_id: Union[int, str], schedule_id: Union[int, str]
     ) -> DeepCrawlSchedule:
-        """Get schedule
+        """
+        Get schedule
 
         >>> connection.get_schedule(1, 2, 3)
         [0 1 3] 2021-03-22 12:09:11+00:00
@@ -657,7 +678,8 @@ class ProjectConnection(ApiConnection):
             self, account_id: Union[int, str], project_id: Union[int, str], schedule_id: Union[int, str],
             schedule_data: dict
     ) -> DeepCrawlSchedule:
-        """Update schedule
+        """
+        Update schedule
 
         >>> connection.update_schedule(1, 2, 3, schedule_data)
         [0 1 3] 2021-04-22 12:09:11+00:00
@@ -683,7 +705,8 @@ class ProjectConnection(ApiConnection):
     def delete_schedule(
             self, account_id: Union[int, str], project_id: Union[int, str], schedule_id: Union[int, str]
     ) -> Response:
-        """Delete current schedule instance
+        """
+        Delete current schedule instance
 
         >>> response = connection.delete_schedule(1, 2, 3)
         >>> response.status_code
@@ -706,7 +729,8 @@ class ProjectConnection(ApiConnection):
     def get_schedules(
             self, account_id: Union[int, str], project_id: Union[int, str], filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlSchedule]:
-        """Get schedules
+        """
+        Get schedules
 
         >>> connection.get_schedules(1, 2)
         [[0 1 3] 2021-03-22 12:09:11+00:00, [0 1 4] 2021-03-22 12:09:11+00:00]
