@@ -4,8 +4,7 @@ Project Upload
 """
 from typing import Union
 
-from deepcrawl.utils import ImmutableAttributesMixin
-from deepcrawl.utils import safe_string_to_datetime
+from deepcrawl.utils import ImmutableAttributesMixin, safe_string_to_datetime
 
 project_upload_extra_fields = (
     "id",
