@@ -2,7 +2,7 @@
 Project
 =======
 """
-from typing import Union, Optional, List
+from typing import List, Optional, Union
 
 from requests import Response
 
@@ -12,8 +12,9 @@ from deepcrawl.projects.issues import DeepCrawlIssue
 from deepcrawl.projects.majestic_settings import MajesticSettings
 from deepcrawl.projects.project_upload import DeepCrawlProjectUpload
 from deepcrawl.projects.schedule import DeepCrawlSchedule
-from deepcrawl.utils import ImmutableAttributesMixin
-from deepcrawl.utils import safe_string_to_datetime
+from deepcrawl.sitemaps.sitemap import DeepCrawlProjectSitemap
+from deepcrawl.utils import ImmutableAttributesMixin, safe_string_to_datetime
+
 from .extractions import DeepCrawlExtraction
 from .project_settings import ProjectSettings
 
@@ -26,7 +27,8 @@ project_extra_fields = (
     "crawls",
     "issues",
     "schedules",
-    "custom_extractions"
+    "custom_extractions",
+    "sitemaps"
 )
 
 project_mutable_fields = project_extra_fields
@@ -60,6 +62,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         self.crawls = []
         self.issues = []
         self.schedules = []
+        self.sitemaps = []
 
         # attributes
         self.crawls_count = project_data.get('crawls_count')
@@ -96,7 +99,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         :return: dictionary with the project fields
         :rtype: dict
         """
-        dict_ = super(DeepCrawlProject, self).to_dict
+        dict_ = super().to_dict
 
         # Remove extra fields
         for attr in project_extra_fields:
@@ -128,7 +131,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def load_project_uploads(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlProjectUpload]:
-        """Loads crawls into current instance
+        """
+        Loads crawls into current instance
 
         >>> self.load_project_uploads()
         [[0 1] filename.csv, [0 1] filename2.csv]
@@ -151,7 +155,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def load_crawls(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlCrawl]:
-        """Loads crawls into current instance
+        """
+        Loads crawls into current instance
 
         >>> self.load_crawls()
         [[0 1 3] 2020-03-22 12:09:11+00:00,
@@ -176,7 +181,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def load_issues(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlIssue]:
-        """Loads issues into current instance
+        """
+        Loads issues into current instance
 
         >>> self.load_issues()
         [[0 1 3] Issue Title, [0 1 3] Issue Title2]
@@ -200,7 +206,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def load_schedules(
             self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlSchedule]:
-        """Loads schedules into current instance
+        """
+        Loads schedules into current instance
 
         >>> self.load_schedules()
         [[0 1 3] 2021-06-22 12:09:11+00:00,
@@ -222,12 +229,37 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         self.schedules = connection.get_schedules(self.account_id, self.id, filters=filters, **kwargs)
         return self.schedules
 
+    def load_project_sitemaps(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlProjectSitemap]:
+        """
+        Loads sitemaps into current instance
+
+        >>> self.load_project_sitemaps()
+        [xSbcfwBTi, aWimWxmnc]
+        >>> self.sitemaps
+        [xSbcfwBTi, aWimWxmnc]
+
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: list of sitemaps
+        :rtype: list
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        self.sitemaps = connection.get_project_sitemaps(self.account_id, self.id, filters=filters, **kwargs)
+        return self.sitemaps
+
     """
     PROJECT
     """
 
     def save(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> 'deepcrawl.projects.DeepCrawlProject':
-        """Save project instance
+        """
+        Save project instance
 
         * if the instance id is None then the project will be created
         * if the instance id is not None then the project will be updated
@@ -247,7 +279,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
             return connection.update_project_settings(self.account_id, self.id, self.project_settings.to_dict)
 
     def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> 'deepcrawl.projects.DeepCrawlProject':
-        """Makes a call to DeepCrawl in order to refresh the current instance.
+        """
+        Makes a call to DeepCrawl in order to refresh the current instance.
 
         >>> self.refresh()
         [0 1] www.test.com Project
@@ -266,7 +299,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def update_settings(
             self, project_settings: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> 'deepcrawl.projects.DeepCrawlProject':
-        """Updates current project instance with another project_settings.
+        """
+        Updates current project instance with another project_settings.
         Settings argument can be dict or a ProjectSettings instance.
 
         >>> self.update_settings(project_settings)
@@ -286,7 +320,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         return self
 
     def delete(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
-        """Delete current project instance
+        """
+        Delete current project instance
 
         >>> response = self.delete()
         >>> response.status_code
@@ -303,18 +338,19 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def add_extractions(
             self, extractions: list, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> 'deepcrawl.projects.DeepCrawlProject':
-        """Add extractions to current project
+        """
+        Add extractions to current project
 
         .. code-block::
 
             extractions = [
                 {
-                  "label": str,
-                  "regex": "regex",
-                  "clean_html_tags": bool,
-                  "match_number_from": int,
-                  "match_number_to": int,
-                  "filter": "regex"
+                    "label": str,
+                    "regex": "regex",
+                    "clean_html_tags": bool,
+                    "match_number_from": int,
+                    "match_number_to": int,
+                    "filter": "regex"
                 }
             ]
 
@@ -348,7 +384,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def create_project_upload(
             self, upload_data: dict, files: list, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlProjectUpload:
-        """Create project upload
+        """
+        Create project upload
 
         >>> self.create_project_upload(upload_data, files)
         [0 1] filename.csv
@@ -369,7 +406,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def get_project_upload(
             self, project_upload_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlProjectUpload:
-        """Get project upload
+        """
+        Get project upload
 
         >>> self.get_project_upload(5)
         [0 1] filename.csv
@@ -388,7 +426,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def enable_project_upload(
             self, project_upload_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlProjectUpload:
-        """Enable project upload
+        """
+        Enable project upload
 
         >>> self.enable_project_upload(5)
         [0 1] filename.csv
@@ -407,7 +446,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def disable_project_upload(
             self, project_upload_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlProjectUpload:
-        """Disable project upload
+        """
+        Disable project upload
 
         >>> self.disable_project_upload(5)
         [0 1] filename.csv
@@ -426,7 +466,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def delete_project_upload(
             self, project_upload_id, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> Response:
-        """Delete current issue instance
+        """
+        Delete current issue instance
 
         >>> response = self.delete_project_upload(5)
         >>> response.status_code
@@ -446,7 +487,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlProjectUpload]:
-        """Get project uploads for current instance
+        """
+        Get project uploads for current instance
 
         * use_cache=True > get_project_uploads will return cached project uploads or will do a call to DeepCrawl
             if project_uploads attribute is empty.
@@ -476,7 +518,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     """
 
     def get_majestic_settings(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> MajesticSettings:
-        """Update majestic settings
+        """
+        Update majestic settings
 
         >>> self.get_majestic_settings()
         [<deepcrawl.projects.majestic_settings.MajesticSettings at 0x108a20600>,
@@ -492,7 +535,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         return self.majestic_settings
 
     def refresh_majestic_settings(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> MajesticSettings:
-        """Refresh majestic settings
+        """
+        Refresh majestic settings
 
         >>> self.refresh_majestic_settings()
         [<deepcrawl.projects.majestic_settings.MajesticSettings at 0x108a20600>,
@@ -510,7 +554,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def update_majestic_settings(
             self, majestic_settings: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> MajesticSettings:
-        """Update majestic settings.
+        """
+        Update majestic settings.
         Majestic settings argument can be dict or a MajesticSettings instance.
 
         >>> self.update_majestic_settings(majestic_settings)
@@ -533,7 +578,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     """
 
     def create_issue(self, issue_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlIssue:
-        """Create issue
+        """
+        Create issue
 
         >>> self.create_issue(issue_data)
         [0 1 4] Issue Title
@@ -552,7 +598,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def get_issue(
             self, issue_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlIssue:
-        """Get issue
+        """
+        Get issue
 
         >>> self.get_issue(3)
         [0 1 3] Issue Title
@@ -571,7 +618,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def update_issue(
             self, issue_id: Union[int, str], issue_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlIssue:
-        """Update issue
+        """
+        Update issue
 
         >>> self.update_issue(3, issue_data)
         [0 1 3] Issue Title updated
@@ -592,7 +640,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def delete_issue(
             self, issue_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> Response:
-        """Delete current issue instance
+        """
+        Delete current issue instance
 
         >>> response = self.delete_issue(3)
         >>> response.status_code
@@ -612,7 +661,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlIssue]:
-        """Get issues for current instance
+        """
+        Get issues for current instance
 
         * use_cache=True > get_issues will return cached issues or will do a call to DeepCrawl if issues attribute is empty.
         * use_cache=False > get_issues will call DeepCrawl api and will override issues attribute.
@@ -641,7 +691,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     """
 
     def start_crawl(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
-        """Start a new crawl
+        """
+        Start a new crawl
 
         >>> response = self.start_crawl()
         >>> response.status_code
@@ -655,7 +706,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         return connection.start_crawl(self.account_id, self.id)
 
     def create_crawl(self, crawl_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlCrawl:
-        """Create crawl
+        """
+        Create crawl
 
         >>> self.create_crawl(crawl_data)
         [0 1 3] 2020-03-22 12:09:11+00:00
@@ -673,7 +725,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def get_crawl(
             self, crawl_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlCrawl:
-        """Get crawl
+        """
+        Get crawl
 
         >>> self.get_crawl(3)
         [0 1 3] 2020-03-22 12:09:11+00:00
@@ -691,7 +744,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def update_crawl(
             self, crawl_id: Union[int, str], crawl_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlCrawl:
-        """Update crawl
+        """
+        Update crawl
 
         >>> self.update_crawl(3, crawl_data)
         [0 1 3] 2020-04-23 11:10:11+00:00
@@ -710,7 +764,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         return crawl
 
     def delete_crawl(self, crawl_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
-        """Delete current crawl instance
+        """
+        Delete current crawl instance
 
         >>> response = self.delete_crawl(3)
         >>> response.status_code
@@ -729,7 +784,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlCrawl]:
-        """Get issues for current instance
+        """
+        Get issues for current instance
 
         * use_cache=True > get_crawls will return cached crawls or will do a call to DeepCrawl if crawls attribute is empty.
         * use_cache=False > get_crawls will call DeepCrawl api and will override crawls attribute.
@@ -760,7 +816,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def create_schedule(
             self, schedule_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlSchedule:
-        """Create schedule
+        """
+        Create schedule
 
         >>> self.create_schedule(schedule_data)
         [0 1 4] 2021-03-22 12:09:11+00:00
@@ -778,7 +835,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def get_schedule(
             self, schedule_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlSchedule:
-        """Get schedule
+        """
+        Get schedule
 
         >>> self.get_schedule(3)
         [0 1 3] 2021-03-22 12:09:11+00:00
@@ -796,7 +854,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def update_schedule(
             self, schedule_id: Union[int, str], schedule_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> DeepCrawlSchedule:
-        """Update schedule
+        """
+        Update schedule
 
         >>> self.update_schedule(3, schedule_data)
         [0 1 3] 2021-04-22 12:09:11+00:00
@@ -817,7 +876,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     def delete_schedule(
             self, schedule_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
     ) -> Response:
-        """Delete current schedule instance
+        """
+        Delete current schedule instance
 
         >>> response = self.delete_schedule(3)
         >>> response.status_code
@@ -836,7 +896,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
             self, use_cache: bool = True,
             connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlSchedule]:
-        """Get schedules for current instance
+        """
+        Get schedules for current instance
 
         * use_cache=True > get_schedules will return cached schedules or will do a call to DeepCrawl if schedules attribute is empty.
         * use_cache=False > get_schedules will call DeepCrawl api and will override schedules attribute.
@@ -859,3 +920,36 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         if use_cache and self.schedules:
             return self.schedules
         return self.load_schedules(connection=connection, filters=filters, **kwargs)
+
+    """
+    PROJECT SITEMAPS
+    """
+
+    def get_project_sitemaps(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlProjectSitemap]:
+        """
+        Get sitemaps for current instance
+
+        * use_cache=True > get_project_sitemaps will return cached sitemaps or will do a call to DeepCrawl if sitemaps attribute is empty.
+        * use_cache=False > get_project_sitemaps will call DeepCrawl api and will override sitemaps attribute.
+
+        >>> self.get_project_sitemaps()
+        [xSbcfwBTi, aWimWxmnc]
+
+        :param use_cache:
+        :type use_cache: bool
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
+        :return: list of sitemaps
+        :rtype: list
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        if use_cache and self.sitemaps:
+            return self.sitemaps
+        return self.load_project_sitemaps(connection=connection, filters=filters, **kwargs)
