@@ -22,6 +22,10 @@ class ImmutableAttributesMixin:
 
     @property
     def to_dict(self) -> dict:
+        """
+        :return: dictionary with all fields
+        :rtype: dict
+        """
         return {x: getattr(self, x, None) for x in self.__slots__}
 
 
